package org.ferris.bible.jmce.daily;

import java.io.Serializable;
import java.util.Calendar;

import org.apache.commons.lang.StringUtils;

public class DailyReadings implements Serializable
{	
	private static final long serialVersionUID = 29034879082357L;
	
	private DailyCalendar day;
	private DailyReading gospel;
	private DailyReading newTestament;
	private DailyReading wisdom;
	private DailyReading oldTestament;	
	
	public DailyReadings() 
	{
		super();
		
		this.day 
			= new DailyCalendar(Calendar.getInstance());	
		
		this.gospel 
			= null;
		
		this.newTestament 
			= null;
		
		this.wisdom 
			= null;
		
		this.oldTestament 
			= null;		
	}
	
	
	public DailyReadings(int month, int day, String gospel, String newTestament, String wisdom, String oldTestament) 
	{
		super();
		
		this.day 
			= new DailyCalendar(Calendar.getInstance().get(Calendar.YEAR),month,day);
		
		this.gospel 
			= DailyReadingFactory.getDailyReading(gospel);
		
		this.newTestament 
			= DailyReadingFactory.getDailyReading(newTestament);
		
		this.wisdom 
			= DailyReadingFactory.getDailyReading(wisdom);
		
		this.oldTestament 
			= DailyReadingFactory.getDailyReading(oldTestament);
	}

	public DailyCalendar getDailyCalendar() {
		return this.day;
	}
	
	public DailyReading getGospel() {
		return gospel;
	}

	public DailyReading getNewTestament() {
		return newTestament;
	}

	public DailyReading getOldTestament() {
		return oldTestament;
	}

	public DailyReading getWisdom() {
		return wisdom;
	}


	/**
	 * @return
	 */
	public boolean hasReadings() {
		return 
			this.gospel != null
			&&
			this.newTestament != null
			&&
			this.wisdom != null
			&&
			this.oldTestament != null
		;
	}
	
	private StringBuilder toHtml;
	public String toHtml()
	{
		if (toHtml != null) {
			return toHtml.toString();
		}
		
		toHtml = new StringBuilder();
		
		toHtml.append("<h2>Daily Bible Readings For ");
		toHtml.append(getDailyCalendar().getMonthSlashDay());
		toHtml.append("</h2>");
		
		if (hasReadings())
		{
			boolean hasOldTestament = !StringUtils.trimToEmpty(getOldTestament().getPassage()).isEmpty();
			boolean hasWisdom	    = !StringUtils.trimToEmpty(getWisdom().getPassage()).isEmpty();
			boolean hasGospel	    = !StringUtils.trimToEmpty(getGospel().getPassage()).isEmpty();
			boolean hasNewTestament = !StringUtils.trimToEmpty(getNewTestament().getPassage()).isEmpty();
			
			toHtml.append("<ol>");
			if (hasOldTestament) { toHtml.append("<li>"+getOldTestament().getPassage()+"</li>"); }
			if (hasWisdom) {toHtml.append("<li>"+getWisdom().getPassage()+"</li>"); }
			if (hasGospel) {toHtml.append("<li>"+getGospel().getPassage()+"</li>"); }
			if (hasNewTestament) {toHtml.append("<li>"+getNewTestament().getPassage()+"</li>"); }
			toHtml.append("</ol>");
			
			if (hasOldTestament) {
				toHtml.append("<hr />");
				toHtml.append(getOldTestament().getContents());	}	
			
			if (hasWisdom) {
				toHtml.append("<hr />");
				toHtml.append(getWisdom().getContents()); }
			
			if (hasGospel) {
				toHtml.append("<hr />");
				toHtml.append(getGospel().getContents()); }
			
			if (hasNewTestament) {
				toHtml.append("<hr />");
				toHtml.append(getNewTestament().getContents()); }			
		} 
		else 
		{
			toHtml.append("<p>Nothing to read today</p>");
		}
		
		return toHtml().toString();
	}
	
}
