package org.ferris.bible.jmce.jobs;

import java.util.Calendar;

import org.apache.log4j.Logger;
import org.ferris.bible.jmce.daily.DailyCalendar;
import org.ferris.bible.jmce.daily.DailyReadings;
import org.ferris.bible.jmce.daily.DailyReadingsEmailMessage;
import org.ferris.bible.jmce.mail.SimpleMailMessage;
import org.ferris.bible.jmce.schedule.ReadingSchedule;
import org.ferris.bible.jmce.schedule.ReadingScheduleFactory;
import org.ferris.bible.jmce.util.PropertiesFactory;
import org.ferris.bible.store.Store;
import org.ferris.bible.store.StoreFactory;
import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

public class DailyReadingsJob implements Job
{
	private Logger log = Logger.getLogger(getClass());
	
	private DailyCalendar dailyCalendar;
	
	public DailyReadingsJob() {
	}
	
	public DailyReadingsJob(DailyCalendar dailyCalendar) 
	{
		this.dailyCalendar = dailyCalendar; 
	}
	
	
	private DailyCalendar getDailyCalendar() 
	{
		if (dailyCalendar == null) 
		{
			log.info("Creating DailyCalendar for today");
			dailyCalendar
				= new DailyCalendar(Calendar.getInstance());
		} 
		
		return dailyCalendar;
	}
	
	public void execute(JobExecutionContext arg0) throws JobExecutionException 
	{		
		log.info("DailyReadingsJob executing()");
		
		try {
			log.info("Creating Reading Schedule");
			ReadingSchedule schedule
				= ReadingScheduleFactory.getReadingSchedule();
			
			
			log.info("Get DailyCalendar.");
			DailyCalendar dc
				= getDailyCalendar();
			
			
			log.info("Getting the readings for today");
			DailyReadings forToday
				= schedule.get(dc);			
			
			if (forToday.hasReadings()) {
				log.info(
					"Read these today: "
					+ forToday.getOldTestament().getPassage() 
					+ ", "
					+ forToday.getWisdom().getPassage()
					+ ", "
					+ forToday.getGospel().getPassage()
					+ ", "
					+ forToday.getNewTestament().getPassage()
				);
			} else {
				log.info("Nothing to read for today.");
			}
			
			log.info("StoreByFileSystem readings for RSS feed");
			store(forToday);
			
			log.info("E-mail readings");
			email(forToday);
						
		} 
		catch (RuntimeException e) {
			log.fatal(e.getMessage(), e);
			throw e;
		}
		
		log.info("DailyReadingsJob done");
	}
	
		
	/**
	 * @param forToday
	 * @param heading
	 * @param all
	 */
	private void store(DailyReadings forToday) 
	{
		log.info("Storing...");
		Store store
			= StoreFactory.getStore();
		store.store(
			  forToday.getDailyCalendar().getYear()
			, forToday.getDailyCalendar().getMonth()
			, forToday.getDailyCalendar().getDay()
			, forToday.toHtml()
//			, forToday.getOldTestament().getPassage()
//			, forToday.getOldTestament().getContents()
//			
//			, forToday.getWisdom().getPassage()
//			, forToday.getWisdom().getContents()
//			
//			, forToday.getGospel().getPassage()
//			, forToday.getGospel().getContents()
//			
//			, forToday.getNewTestament().getPassage()
//			, forToday.getNewTestament().getContents()
		);
	}

	private void email(DailyReadings readings) {
		DailyReadingsEmailMessage m
			= new DailyReadingsEmailMessage(readings);
		email(
			  m.getFromAddress()
			, m.getFromName()
			, m.getToAddress()
			, m.getToName()
			, m.getSubject()
			, m.getMessage()
		);
		
	}
	
	private void email(
		  String fromAddress
		, String fromName
		, String toAddress
		, String toName
		, String subject
		, String message
	)
	{
		log.info("E-mailing...");
		try {
			
			SimpleMailMessage smm 
				= new SimpleMailMessage(PropertiesFactory.getHost());
			smm.setFrom(fromAddress, fromName);
			smm.addTo(toAddress, toName);			
			smm.setSubject(subject);				  
			smm.setText(message);		
			smm.sendAsHtml();
		}
		catch (Throwable e) {
			log.fatal(e.getMessage(), e);
		}
	}
}
