package org.ferris.bible.jmce.main;

import org.apache.log4j.Logger;
import org.ferris.bible.jmce.daily.DailyCalendar;
import org.ferris.bible.jmce.jobs.DailyReadingsJob;
import org.quartz.JobDetail;
import org.quartz.Scheduler;
import org.quartz.Trigger;
import org.quartz.TriggerUtils;
import org.quartz.impl.StdSchedulerFactory;

public class Main 
{
	private static Logger log = Logger.getLogger(Main.class);
	
	/**
	 * @param args
	 */
	public static void main(String[] args) 	
	{		
		try {
			new Main(args);
		} catch (Throwable e) {
			log.fatal(e.getMessage(), e);
			e.printStackTrace();
		}
	}
	
	
	
	public Main(String[] args) throws Throwable
	{
		log.info("The main() method of Ferris Bible has been called");
	
		if (args.length > 0) 
		{
			String arg0 = args[0];
			if (arg0.equals("--help")) 
			{
				System.out.println("  ");
				System.out.println("USAGE:  ");
				System.out.println(" java bible.jar --nojmce <month 1-12> <day 1-31> <year>");				
			}
			else
			if (arg0.equals("--nojmce")) 
			{
				DailyReadingsJob job 
					= null;
				
				if (args.length >= 3) 
				{
					int month = Integer.parseInt(args[1]);
					int day = Integer.parseInt(args[2]);
					int year = Integer.parseInt(args[3]);
					job = new DailyReadingsJob(new DailyCalendar(year, month, day));
				}
				else {
					job = new DailyReadingsJob();
				}
				
				job.execute(null);
			}
		} else {
			two();
		}
	}

	private void two()
	throws Exception {
		//	Grab the Scheduler instance from the Factory 
		log.info("Create Scheduler");
        Scheduler scheduler = StdSchedulerFactory.getDefaultScheduler();

		log.info("Create JobDetail");
		JobDetail jobDetail 
			= new JobDetail(
				DailyReadingsJob.class.getSimpleName(),
			    null,
			    DailyReadingsJob.class
			);
		
		log.info("Create Trigger");
		Trigger trigger 
		    //= TriggerUtils.makeImmediateTrigger(DailyReadingsJob.class.getSimpleName(), 0, 0);
			= TriggerUtils.makeDailyTrigger(DailyReadingsJob.class.getSimpleName(),1,0); //1:00am
		
		log.info("Schedule job");
		scheduler.scheduleJob(jobDetail, trigger);
		
        log.info("Start scheduler");
        scheduler.start();
	}
}
