package org.ferris.bible.jmce.schedule;

import java.io.IOException;
import java.io.InputStream;
import java.util.Iterator;
import java.util.List;

import org.apache.commons.io.IOUtils;
import org.apache.log4j.Logger;
import org.ferris.bible.jmce.daily.DailyReadings;
import org.ferris.bible.jmce.daily.DailyReadingsFactory;

public class ReadingScheduleFactory 
{
	private static Logger log = Logger.getLogger(ReadingScheduleFactory.class);
	
	public static ReadingSchedule getReadingSchedule()
	{
		String book 
			= "/"
			  + ReadingScheduleFactory
			  		.class
			  		.getPackage()
			  		.getName()
			  		.replaceAll("\\.", "/")
			  +"/Book1.txt";
		
		InputStream is
			= ReadingScheduleFactory.class.getResourceAsStream(book);
		
		if (is == null) {
			throw new RuntimeException("Book "+book+" not found on classpath.");
		}
		
		List<String> lines = null; {
			try {
				lines = IOUtils.readLines(is);
			} catch (IOException e) {
				throw new RuntimeException("Problem reading lines into list.", e);
			}
		}
		
		ReadingSchedule schedule
			= new ReadingSchedule();
		
		Iterator<String> itr = lines.iterator();
		itr.next(); // heading
		while(itr.hasNext()) {
			String line = itr.next();
			DailyReadings dr = DailyReadingsFactory.getDailyReadings(line);
			schedule.put(dr.getDailyCalendar(), dr);
		}
		
		log.info(
			"Schedule has "+schedule.size()+" daily readings."
		);
		return schedule;
	}
}
